@@ -1,23 +1,13 @@
-/*************************************************************************
- *  Copyright (C) 2008, 2010 by Volker Lanz <vl@fidra.de>                *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2016-2018 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2018 Huzaifa Faruqui <huzaifafaruqui@gmail.com>
 
-#if !defined(JOB__H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
-#define JOB__H
+#ifndef KPMCORE_JOB_H
+#define KPMCORE_JOB_H
 
 #include "fs/filesystem.h"
 
@@ -49,10 +39,10 @@ class LIBKPMCORE_EXPORT Job : public QObject
 
 public:
     /** Status of this Job */
-    enum JobStatus {
-        Pending = 0,        /**< Pending, not yet run */
-        Success,            /**< Successfully run */
-        Error               /**< Running generated an error */
+    enum class Status : int {
+        Pending,        /**< Pending, not yet run */
+        Success,        /**< Successfully run */
+        Error           /**< Running generated an error */
     };
 
 protected:
@@ -73,14 +63,15 @@ public:
     virtual QString description() const = 0; /**< @return the Job's description */
     virtual bool run(Report& parent) = 0; /**< @param parent parent Report to add new child to for this Job @return true if successfully run */
 
-    virtual QIcon statusIcon() const;
+    virtual QString statusIcon() const;
     virtual QString statusText() const;
 
-    JobStatus status() const {
+    Status status() const {
         return m_Status;    /**< @return the Job's current status */
     }
 
     void emitProgress(int i);
+    void updateReport(const QString& report);
 
 protected:
     bool copyBlocks(Report& report, CopyTarget& target, CopySource& source);
@@ -89,12 +80,13 @@ protected:
     Report* jobStarted(Report& parent);
     void jobFinished(Report& report, bool b);
 
-    void setStatus(JobStatus s) {
+    void setStatus(Status s) {
         m_Status = s;
     }
 
 private:
-    JobStatus m_Status;
+    Report *m_Report;
+    Status m_Status;
 };
 
 #endif
